@@ -1,3 +1,4 @@
+# from enum import Enum
 from time import strftime
 from os import mkdir, path, getcwd, environ
 from PIL import Image
@@ -9,12 +10,17 @@ from profanity_check import predict as profanity_predict
 import traceback
 from multiskin.clean.clean_skin import clean_skin
 
+# class CreationType(Enum):
+#     SKIN = 1
+#     CAPE = 2
+
 @dataclass
 class InferConfig:
     prompts: List[str]
     num_inference_steps: int = 50
     width: int = 512
     height: int = 512
+    creation_type: str = "SKIN"
 
 def dummy(images, **kwargs):
             return images, False
@@ -28,11 +34,12 @@ class Model:
     Uses HuggingFace libs to download the model, configure it for CUDA.
     infer() function
     '''
-    # model_path="src/TrainedModel", 
-    model_path: str = "joshelgar/premesh-mc-skin-2k"
-    output_folder: str = "generated_images"
+    model_path: str = None
+    skin_output_folder: str = "generated_images"
+    cape_output_folder = "generated_capes" # change cape.py if changing this
 
-    def __init__(self, hf_token: str = "", mac: bool = False):
+    def __init__(self, hf_token: str = "", mac: bool = False, model_path: str ="joshelgar/premesh-mc-skin-2k"):
+        self.model_path = model_path
         login(environ.get("HUGGING_FACE_TOKEN", hf_token))
         self.pipe = StableDiffusionPipeline.from_pretrained(self.model_path)
         if mac:
@@ -52,7 +59,7 @@ class Model:
 
     def make_output_folder(self):
         print("Creating output folder")
-        dir = path.join(getcwd(), f'./{self.output_folder}')
+        dir = path.join(getcwd(), f'./{self.skin_output_folder}')
         if not path.isdir(dir):
             mkdir(dir)
 
@@ -66,17 +73,20 @@ class Model:
 
     def create_filename(self, prompt: str):
         # Clean and add current time
-        currtime = strftime("%Y%m%d-%H%M%S")
+        print(f"Creating filename from prompt: {prompt}")
         keepcharacters = (' ', '_')
-        cleaned_prompt = "".join(c for c in prompt if c.isalnum() or c in keepcharacters).rstrip()
-        prompt_as_list = prompt.split()
-        prompt_as_list.append(currtime)
-        filename = "_".join(cleaned_prompt)
-        return filename[:128] # cap at 128 chars
+        shortened_prompt = prompt[:32]  # cap at about 32 chars + currtime string length
+        cleaned_prompt = "".join(c for c in shortened_prompt if c.isalnum() or c in keepcharacters).rstrip()
+        prompt_as_list = cleaned_prompt.split()
+        currtime = strftime("%Y%m%d-%H%M%S")
+        currtime_list = [currtime]
+        currtime_list.extend(prompt_as_list)
+        filename = "_".join(currtime_list)
+        return filename
 
 
     def infer(self, infer_config: InferConfig) -> List[str]:
-        ''' 
+        '''
         Runs the model based on a supplied RunConfig (prompts, inf steps, resolution etc.)
         Returns -> List of filenames of resized images
         '''
@@ -87,15 +97,22 @@ class Model:
                 raise ProfanityError
             for idx, prompt in enumerate(prompts):
                 print(f"Generating prompt [{idx}/{len(prompts)}]: [{prompt}]...")
-                images: List[Image.Image] = self.pipe(f"{prompt} mc", **self.pipeline_args(infer_config=infer_config)).images
+                tokened_prompt = f"{prompt} mc" if infer_config.creation_type is "SKIN" else f"{prompt}, sjh style"
+                images: List[Image.Image] = self.pipe(tokened_prompt, **self.pipeline_args(infer_config=infer_config)).images
                 filename = self.create_filename(prompt=prompt)
-                for image in images:
-                    resized = image.resize((64, 64), resample=Image.Resampling.NEAREST)
-                    cleaned = clean_skin(resized)
-                    final_filename = f"./{self.output_folder}/{filename}_resized.png"
-                    cleaned.save(final_filename)
-                    generated_filenames.append(final_filename)
-
+                if infer_config.creation_type is "SKIN":
+                    for image in images:
+                        resized = image.resize((64, 64), resample=Image.Resampling.NEAREST)
+                        cleaned = clean_skin(resized)
+                        final_filename = f"./{self.skin_output_folder}/{filename}_resized.png"
+                        cleaned.save(final_filename)
+                        generated_filenames.append(final_filename)
+                elif infer_config.creation_type is "CAPE":
+                    for image in images:
+                        final_filename = f"./{self.cape_output_folder}/{filename}.png"
+                        image.save(final_filename)
+                        generated_filenames.append(final_filename)
+                        
             return generated_filenames
         except Exception as e:
             print(traceback.format_exc())
